( cd usr/lib ; rm -rf libpangocairo-1.0.so )
( cd usr/lib ; ln -sf libpangocairo-1.0.so.0.1600.4 libpangocairo-1.0.so )
( cd usr/lib ; rm -rf libpangocairo-1.0.so.0 )
( cd usr/lib ; ln -sf libpangocairo-1.0.so.0.1600.4 libpangocairo-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoxft-1.0.so )
( cd usr/lib ; ln -sf libpangoxft-1.0.so.0.1600.4 libpangoxft-1.0.so )
( cd usr/lib ; rm -rf libpangoxft-1.0.so.0 )
( cd usr/lib ; ln -sf libpangoxft-1.0.so.0.1600.4 libpangoxft-1.0.so.0 )
( cd usr/lib ; rm -rf libpangoft2-1.0.so )
( cd usr/lib ; ln -sf libpangoft2-1.0.so.0.1600.4 libpangoft2-1.0.so )
( cd usr/lib ; rm -rf libpangoft2-1.0.so.0 )
( cd usr/lib ; ln -sf libpangoft2-1.0.so.0.1600.4 libpangoft2-1.0.so.0 )
( cd usr/lib ; rm -rf libpangox-1.0.so )
( cd usr/lib ; ln -sf libpangox-1.0.so.0.1600.4 libpangox-1.0.so )
( cd usr/lib ; rm -rf libpangox-1.0.so.0 )
( cd usr/lib ; ln -sf libpangox-1.0.so.0.1600.4 libpangox-1.0.so.0 )
( cd usr/lib ; rm -rf libpango-1.0.so )
( cd usr/lib ; ln -sf libpango-1.0.so.0.1600.4 libpango-1.0.so )
( cd usr/lib ; rm -rf libpango-1.0.so.0 )
( cd usr/lib ; ln -sf libpango-1.0.so.0.1600.4 libpango-1.0.so.0 )
